@@ -8,7 +8,7 @@ import {
   SYSTEM_USER_UUID,
   TASK_DELETE_RECORDED_IN_ERROR_REASON_ID,
 } from '@tamanu/constants';
-import { InvalidOperationError } from '@tamanu/shared/errors';
+import { InvalidOperationError } from '@tamanu/errors';
 import { dischargeOutpatientEncounters } from '@tamanu/shared/utils/dischargeOutpatientEncounters';
 import { getCurrentDateTimeString } from '@tamanu/utils/dateTime';
 
@@ -320,6 +320,11 @@ export class Encounter extends Model {
       as: 'appointments',
     });
 
+    this.hasMany(models.Appointment, {
+      foreignKey: 'linkEncounterId',
+      as: 'linkedAppointments',
+    });
+
     // this.hasMany(models.Procedure);
     // this.hasMany(models.Report);
   }
@@ -381,9 +386,9 @@ export class Encounter extends Model {
     `;
   }
 
-  static buildSyncLookupQueryDetails() {
+  static async buildSyncLookupQueryDetails() {
     return {
-      select: buildEncounterLinkedLookupSelect(this, {
+      select: await buildEncounterLinkedLookupSelect(this, {
         isLabRequestValue: 'new_labs.encounter_id IS NOT NULL',
       }),
       joins: `
@@ -494,7 +499,7 @@ export class Encounter extends Model {
 
   async addSystemNote(content: string, date: string, user: ModelProperties<User>) {
     return (this as any).createNote({
-      noteType: NOTE_TYPES.SYSTEM,
+      noteTypeId: NOTE_TYPES.SYSTEM,
       date,
       content,
       ...(user?.id && { authorId: user?.id }),
