@@ -15,13 +15,11 @@ import {
   startSyncCommand,
   startTasksCommand,
   syncCommand,
+  upgradeCommand,
 } from './subCommands';
 
 async function run() {
-  program
-    .version(version)
-    .description('Tamanu Facility server')
-    .name('node dist');
+  program.version(version).description('Tamanu Facility server').name('node dist');
 
   program.addCommand(startAllCommand, { isDefault: true });
   program.addCommand(startApiCommand);
@@ -32,6 +30,7 @@ async function run() {
   program.addCommand(migrateCommand);
   program.addCommand(migrateAppointmentsToLocationGroupsCommand);
   program.addCommand(shellCommand);
+  program.addCommand(upgradeCommand);
 
   await program.parseAsync(process.argv);
 }
