@@ -108,10 +108,7 @@ const updateInvoiceSchema = z
   .object({
     discount: z
       .object({
-        id: z
-          .string()
-          .uuid()
-          .default(uuidv4),
+        id: z.string().uuid().default(uuidv4),
         percentage: z.coerce
           .number()
           .min(0)
@@ -124,10 +121,7 @@ const updateInvoiceSchema = z
       .optional(),
     insurers: z
       .object({
-        id: z
-          .string()
-          .uuid()
-          .default(uuidv4),
+        id: z.string().uuid().default(uuidv4),
         percentage: z.coerce
           .number()
           .min(0)
@@ -143,29 +137,23 @@ const updateInvoiceSchema = z
       ),
     items: z
       .object({
-        id: z
-          .string()
-          .uuid()
-          .default(uuidv4),
+        id: z.string().uuid().default(uuidv4),
         orderDate: z.string().date(),
         orderedByUserId: z.string(),
         productId: z.string(),
         productName: z.string(),
-        productPrice: z.coerce.number().transform(amount => round(amount, 2)),
+        productPrice: z.coerce
+          .number()
+          .transform(amount => round(amount, 2))
+          .optional(),
         productCode: z.string().default(''),
         productDiscountable: z.boolean().default(true),
         quantity: z.coerce.number().default(1),
         note: z.string().optional(),
-        sourceId: z
-          .string()
-          .uuid()
-          .optional(),
+        sourceId: z.string().uuid().optional(),
         discount: z
           .object({
-            id: z
-              .string()
-              .uuid()
-              .default(uuidv4),
+            id: z.string().uuid().default(uuidv4),
             type: z.enum(Object.values(INVOICE_ITEMS_DISCOUNT_TYPES)),
             amount: z.coerce.number().transform(amount => round(amount, 2)),
             reason: z.string().optional(),
@@ -252,6 +240,7 @@ invoiceRoute.put(
 
       for (const item of data.items) {
         const { discount: itemDiscount, ...itemData } = item;
+
         //update or create item
         await req.models.InvoiceItem.upsert({ ...itemData, invoiceId }, { transaction });
 
